#!/bin/bash

# JJ 21.3.2013: this scripts is called from pam session authentication module
# to create a symlink from /home/luser -> /home/ad/lusers-home-directory/
# and other relevant staff, which cannot be done with plain user access

# mjr 18.4.2013. Handle prefixed profiles.
# mjr 21.5.2014. Ditch profiles for 14.04
# JJ 18.9.2014. handle luser@cs
# JJ 8.3.2016. Remove tktl-csfs
# JJ 13.9.2016:  rewrite for cubbli 16.04
# JJ 22.8.2017:  support /etc/cubbli/flags/home-directory
# JJ 5.9.2018:  rewrite for cubbli 18.04

log() {
   logger -t "$0" "[$$] $*"
}

log "Starting: PAM_SERVICE=$PAM_SERVICE PAM_USER=$PAM_USER PAM_TYPE=$PAM_TYPE"

if [ "$PAM_TYPE" != "open_session" ]; then
  log "exiting, PAM_TYPE != open_session"
  exit 0
fi


# Check that we have a uid we like
uid="$(id -u "$PAM_USER")"
if [ "x$uid" == "x" ] || [ $uid -lt 1000 ]; then
  log "Ignoring uid=$uid";
  exit 0
fi

if ! getent passwd $PAM_USER | egrep -q ":/home/$PAM_USER:[^:]+$"; then
  log "Exiting for $PAM_USER: home directory not /home/luser, not updating symlinks"
  exit 0
fi

c=$(echo "$PAM_USER" | cut -c1)

if [ -e /etc/cubbli/flags/use-ad-home ] || [ -e /etc/cubbli/flags/home-directory ]; then
  # Create a /home/luser -> /home/real/home symlink
  if [ -e /etc/cubbli/flags/home-directory ]; then
    adpath=$(cat /etc/cubbli/flags/home-directory)/$PAM_USER   
  elif sudo -n -u $PAM_USER test -e /cs/home/$PAM_USER/.cubbli-home ; then
    adpath="./fs/$PAM_USER"
  else
    adpath=./ad/lxhome/$c/$PAM_USER/Linux
    if ! sudo -n -u $PAM_USER mkdir -p /home/$adpath; then
      log "FAILED mkdir -p /home/$adpath"
      echo "Sorry, Your AD home directory ($adpath) is not accessible." 1>&2
      exit 1
    fi
  fi
  log "User $PAM_USER home directory is $adpath"
  if [ "$(readlink /home/$PAM_USER)" != "$adpath" ]; then
    if ln -T -sf "$adpath" "/home/$PAM_USER"; then
      log "Symlink /home/$PAM_USER -> $adpath created."
    else
      log "Symlink /home/$PAM_USER -> $adpath FAILED."
      echo "Failed to create /home/$PAM_USER symlink. Home directory probably is not available." 1>&2       
      exit 1
    fi
  else
      log "Symlink /home/$PAM_USER -> $adpath exists."
  fi
elif [ "$PAM_SERVICE" = lightdm -o "$PAM_SERVICE" = gdm-password -o "$PAM_SERVICE" = gdm-vmwcred ]; then
  # Local user setup, but only when logged in from lightdm
  # And user is not using existing home directory
  log "User $PAM_USER tagged as local user. Adding groups."
  /usr/sbin/adduser $PAM_USER lpadmin
  /usr/sbin/addgroup --system --gid 250 local
  /usr/sbin/adduser $PAM_USER local
  # Create the local home directory if needed
  if [ -e "/home/$PAM_USER" -a ! -L "/home/$PAM_USER" ]; then
    log "Local home is not a symlink."
  else 
    local_dir="/home/local/$PAM_USER"
    mkdir -p  --mode 0755 /home/local
    if [ ! -z "$local_dir" ] && [ ! -d "$local_dir" ]; then
      log "Creating local home directory $localdir"
      mkdir -p  --mode 0700 "$local_dir" && 
      chown $(id -u $PAM_USER).$(id -g $PAM_USER) $local_dir
    fi
    if [ "$(readlink /home/$PAM_USER)" != ./local/$PAM_USER ]; then
      log "Creating local home symlink"
      ln -T -sf "./local/$PAM_USER" "/home/$PAM_USER"
    fi
  fi
fi


exit 0

